summaryrefslogtreecommitdiff
path: root/src/basic/fs-util.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/basic/fs-util.c')
-rw-r--r--src/basic/fs-util.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/basic/fs-util.c b/src/basic/fs-util.c
index 0ca4656fdd..b30cec4f92 100644
--- a/src/basic/fs-util.c
+++ b/src/basic/fs-util.c
@@ -711,10 +711,10 @@ int chase_symlinks(const char *path, const char *original_root, unsigned flags,
if (child < 0) {
if (errno == ENOENT &&
- (flags & CHASE_NON_EXISTING) &&
+ (flags & CHASE_NONEXISTENT) &&
(isempty(todo) || path_is_safe(todo))) {
/* If CHASE_NON_EXISTING is set, and the path does not exist, then that's OK, return
* what we got so far. But don't allow this if the remaining path contains "../ or "./"
* or something else weird. */
@@ -711,10 +711,10 @@ int chase_symlinks(const char *path, const char *original_root, unsigned flags,
(isempty(todo) || path_is_safe(todo))) {
- /* If CHASE_NON_EXISTING is set, and the path does not exist, then that's OK, return
+ /* If CHASE_NONEXISTENT is set, and the path does not exist, then that's OK, return
* what we got so far. But don't allow this if the remaining path contains "../ or "./"
* or something else weird. */